@@ -398,15 +398,16 @@ custom_command_entry_changed_cb (GtkEntry *entry)
 
   command = gtk_entry_get_text (entry);
 
-  if (g_shell_parse_argv (command, NULL, NULL, &error))
+  if (command[0] == '\0' ||
+      g_shell_parse_argv (command, NULL, NULL, &error))
     {
-      gtk_entry_set_icon_from_stock (entry, GTK_PACK_END, NULL);
+      gtk_entry_set_icon_from_icon_name (entry, GTK_PACK_END, NULL);
     }
   else
     {
       char *tooltip;
 
-      gtk_entry_set_icon_from_stock (entry, GTK_PACK_END, GTK_STOCK_DIALOG_WARNING);
+      gtk_entry_set_icon_from_icon_name (entry, GTK_PACK_END, "dialog-warning");
 
       tooltip = g_strdup_printf (_("Error parsing command: %s"), error->message);
       gtk_entry_set_icon_tooltip_text (entry, GTK_PACK_END, tooltip);
@@ -941,14 +942,6 @@ terminal_profile_edit (GSettings  *profile,
   g_settings_bind (profile, TERMINAL_PROFILE_TITLE_KEY,
                    gtk_builder_get_object (builder, "title-entry"), "text",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_settings_bind_with_mapping (profile, TERMINAL_PROFILE_TITLE_MODE_KEY,
-                                gtk_builder_get_object (builder,
-                                                        "title-mode-combobox"),
-                                "active",
-                                G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET,
-                                (GSettingsBindGetMapping) string_to_enum,
-                                (GSettingsBindSetMapping) enum_to_string,
-                                terminal_title_mode_get_type, NULL);
   g_settings_bind (profile, TERMINAL_PROFILE_UPDATE_RECORDS_KEY,
                    gtk_builder_get_object (builder,
                                            "update-records-checkbutton"),
