@@ -41,6 +41,7 @@
 #include "terminal-defines.h"
 #include "terminal-prefs.h"
 
+#include <sys/wait.h>
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
@@ -102,9 +103,10 @@ maybe_migrate_settings (TerminalApp *app)
 #endif
     NULL 
   };
-  guint version;
   int status;
   GError *error = NULL;
+#endif /* ENABLE_MIGRATION */
+  guint version;
 
   version = g_settings_get_uint (terminal_app_get_global_settings (app), TERMINAL_SETTING_SCHEMA_VERSION);
   if (version >= TERMINAL_SCHEMA_VERSION) {
@@ -113,6 +115,7 @@ maybe_migrate_settings (TerminalApp *app)
     return;
   }
 
+#ifdef ENABLE_MIGRATION
   if (!g_spawn_sync (NULL /* our home directory */,
                      (char **) argv,
                      NULL /* envv */,
@@ -264,9 +267,7 @@ app_menu_help_cb (GSimpleAction *action,
                   GVariant      *parameter,
                   gpointer       user_data)
 {
-        GtkApplication *application = user_data;
-
-        terminal_util_show_help (NULL, gtk_application_get_active_window (application));
+  terminal_util_show_help (NULL, NULL);
 }
 
 static void
@@ -274,9 +275,22 @@ app_menu_about_cb (GSimpleAction *action,
                    GVariant      *parameter,
                    gpointer       user_data)
 {
-  GtkApplication *application = user_data;
+  terminal_util_show_about (NULL);
+}
 
-  terminal_util_show_about (gtk_application_get_active_window (application));
+static void
+app_menu_quit_cb (GSimpleAction *action,
+                  GVariant      *parameter,
+                  gpointer       user_data)
+{
+  GtkApplication *application = user_data;
+  GtkWindow *window;
+
+  window = gtk_application_get_active_window (application);
+  if (TERMINAL_IS_WINDOW (window))
+    terminal_window_request_close (TERMINAL_WINDOW (window));
+  else /* a dialogue */
+    gtk_widget_destroy (GTK_WIDGET (window));
 }
 
 /* Class implementation */
@@ -297,7 +311,8 @@ terminal_app_startup (GApplication *application)
   const GActionEntry app_menu_actions[] = {
     { "preferences", app_menu_preferences_cb,   NULL, NULL, NULL },
     { "help",        app_menu_help_cb,          NULL, NULL, NULL },
-    { "about",       app_menu_about_cb,         NULL, NULL, NULL }
+    { "about",       app_menu_about_cb,         NULL, NULL, NULL },
+    { "quit",        app_menu_quit_cb,          NULL, NULL, NULL }
   };
 
   GtkBuilder *builder;
@@ -342,6 +357,10 @@ terminal_app_init (TerminalApp *app)
 
   /* Terminal global settings */
   app->global_settings = g_settings_new (TERMINAL_SETTING_SCHEMA);
+  g_settings_bind (app->global_settings, TERMINAL_SETTING_DARK_THEME_KEY,
+                   gtk_settings_get_default (),
+                   "gtk-application-prefer-dark-theme",
+                   G_SETTINGS_BIND_GET);
 
   /* Check if we need to migrate from gconf to dconf */
   maybe_migrate_settings (app);
@@ -358,7 +377,7 @@ terminal_app_init (TerminalApp *app)
                     app);
 
   settings = g_settings_get_child (app->global_settings, "keybindings");
-  terminal_accels_init (settings);
+  terminal_accels_init (G_APPLICATION (app), settings);
   g_object_unref (settings);
 }
 
