@@ -28,7 +28,7 @@ G_BEGIN_DECLS
 #define TERMINAL_FACTORY_OBJECT_PATH            TERMINAL_OBJECT_PATH_PREFIX "/Factory0"
 #define TERMINAL_FACTORY_INTERFACE_NAME         TERMINAL_OBJECT_INTERFACE_PREFIX ".Factory0"
 
-#define TERMINAL_RECEIVER_OBJECT_PATH_PREFIX    TERMINAL_OBJECT_PATH_PREFIX "/Terminals"
+#define TERMINAL_RECEIVER_OBJECT_PATH_FORMAT    TERMINAL_OBJECT_PATH_PREFIX "/window/%u/terminal/%s"
 #define TEMRINAL_RECEIVER_INTERFACE_NAME        TERMINAL_OBJECT_INTERFACE_PREFIX ".Terminal0"
 
 G_END_DECLS
