@@ -24,15 +24,12 @@
 
 G_BEGIN_DECLS
 
-typedef enum
-{
-  TERMINAL_TITLE_REPLACE,
-  TERMINAL_TITLE_BEFORE,
-  TERMINAL_TITLE_AFTER,
-  TERMINAL_TITLE_IGNORE
-} TerminalTitleMode;
+typedef enum {
+  TERMINAL_NEW_TERMINAL_MODE_WINDOW,
+  TERMINAL_NEW_TERMINAL_MODE_TAB
+} TerminalNewTerminalMode;
 
-typedef enum 
+typedef enum
 {
   TERMINAL_EXIT_CLOSE,
   TERMINAL_EXIT_RESTART,
