@@ -86,20 +86,18 @@ profile_cell_data_func (GtkTreeViewColumn *tree_column,
 {
   GSettings *profile;
   const char *text;
-  char *uuid;
   GValue value = { 0, };
 
   gtk_tree_model_get (tree_model, iter, (int) COL_PROFILE, &profile, (int) -1);
   g_settings_get (profile, TERMINAL_PROFILE_VISIBLE_NAME_KEY, "&s", &text);
-  uuid = terminal_settings_list_dup_uuid_from_child (data->profiles_list, profile);
 
   g_value_init (&value, G_TYPE_STRING);
-  g_value_take_string (&value,
-                       g_markup_printf_escaped ("%s\n<span size=\"small\" font_family=\"monospace\">%s</span>",
-                                                strlen (text) > 0 ? text : _("Unnamed"), 
-                                                uuid));
-  g_free (uuid);
-  g_object_set_property (G_OBJECT (cell), "markup", &value);
+  if (text[0])
+    g_value_set_string (&value, text);
+  else
+    g_value_set_static_string (&value, _("Unnamed"));
+
+  g_object_set_property (G_OBJECT (cell), "text", &value);
   g_value_unset (&value);
 
   g_object_unref (profile);
@@ -396,9 +394,9 @@ profile_list_delete_button_clicked_cb (GtkWidget *button,
                                    name);
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          GTK_STOCK_CANCEL,
+                          _("_Cancel"),
                           GTK_RESPONSE_REJECT,
-                          GTK_STOCK_DELETE,
+                          _("_Delete"),
                           GTK_RESPONSE_ACCEPT,
                           NULL);
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
@@ -591,6 +589,7 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
   GtkWidget *dialog, *tree_view;
   GtkWidget *show_menubar_button, *disable_mnemonics_button, *disable_menu_accel_button;
   GtkWidget *tree_view_container, *new_button, *edit_button, *clone_button, *remove_button;
+  GtkWidget *dark_theme_button, *new_terminal_mode_combo;
   GtkWidget *default_hbox, *default_label;
   GtkTreeSelection *selection;
   GSettings *settings;
@@ -611,6 +610,8 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
                                        "preferences-dialog",
                                        "preferences-dialog", &dialog,
                                        "default-show-menubar-checkbutton", &show_menubar_button,
+                                       "dark-theme-checkbutton", &dark_theme_button,
+                                       "new-terminal-mode-combobox", &new_terminal_mode_combo,
                                        "disable-mnemonics-checkbutton", &disable_mnemonics_button,
                                        "disable-menu-accel-checkbutton", &disable_menu_accel_button,
                                        "accelerators-treeview", &tree_view,
@@ -638,6 +639,18 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 
+  g_settings_bind (settings,
+                   TERMINAL_SETTING_DARK_THEME_KEY,
+                   dark_theme_button,
+                   "active",
+                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
+  g_settings_bind (settings,
+                   TERMINAL_SETTING_NEW_TERMINAL_MODE_KEY,
+                   new_terminal_mode_combo,
+                   "active-id",
+                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
   /* Keybindings tab */
 
   g_settings_bind (settings,
