@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <sys/wait.h>
 #include <fcntl.h>
+#include <uuid.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -70,13 +71,12 @@ typedef struct
 
 struct _TerminalScreenPrivate
 {
+  char *uuid;
+
   GSettings *profile; /* never NULL */
   guint profile_changed_id;
   guint profile_forgotten_id;
-  char *raw_title, *raw_icon_title;
-  char *cooked_title, *cooked_icon_title;
-  char *override_title;
-  gboolean icon_title_set;
+  char *title;
   char *initial_working_directory;
   char **initial_env;
   char **override_command;
@@ -84,7 +84,6 @@ struct _TerminalScreenPrivate
   int child_pid;
   int pty_fd;
   double font_scale;
-  gboolean user_title; /* title was manually set */
   GSList *match_tags;
   guint launch_child_source_id;
 };
@@ -104,6 +103,7 @@ enum {
   PROP_ICON_TITLE,
   PROP_ICON_TITLE_SET,
   PROP_TITLE,
+  PROP_DESCRIPTION,
   PROP_INITIAL_ENVIRONMENT
 };
 
@@ -144,11 +144,6 @@ static void terminal_screen_icon_title_changed        (VteTerminal *vte_terminal
 
 static void update_color_scheme                      (TerminalScreen *screen);
 
-static gboolean terminal_screen_format_title (TerminalScreen *screen, const char *raw_title, char **old_cooked_title);
-
-static void terminal_screen_cook_title      (TerminalScreen *screen);
-static void terminal_screen_cook_icon_title (TerminalScreen *screen);
-
 static char* terminal_screen_check_match       (TerminalScreen            *screen,
                                                 int                   column,
                                                 int                   row,
@@ -305,9 +300,15 @@ terminal_screen_init (TerminalScreen *screen)
   GtkTargetEntry *targets;
   int n_targets;
   guint i;
+  uuid_t u;
+  char uuidstr[37];
 
   priv = screen->priv = G_TYPE_INSTANCE_GET_PRIVATE (screen, TERMINAL_TYPE_SCREEN, TerminalScreenPrivate);
 
+  uuid_generate (u);
+  uuid_unparse (u, uuidstr);
+  priv->uuid = g_strdup (uuidstr);
+
   vte_terminal_set_mouse_autohide (terminal, TRUE);
   vte_terminal_set_background_image (terminal, NULL);
   vte_terminal_set_scroll_background (terminal, FALSE);
@@ -348,9 +349,6 @@ terminal_screen_init (TerminalScreen *screen)
   gtk_target_table_free (targets, n_targets);
   gtk_target_list_unref (target_list);
 
-  priv->override_title = NULL;
-  priv->user_title = FALSE;
-  
   g_signal_connect (screen, "window-title-changed",
                     G_CALLBACK (terminal_screen_window_title_changed),
                     screen);
@@ -396,6 +394,9 @@ terminal_screen_get_property (GObject *object,
       case PROP_TITLE:
         g_value_set_string (value, terminal_screen_get_title (screen));
         break;
+      case PROP_DESCRIPTION:
+        g_value_take_string (value, terminal_screen_get_description (screen));
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -421,6 +422,7 @@ terminal_screen_set_property (GObject *object,
       case PROP_ICON_TITLE:
       case PROP_ICON_TITLE_SET:
       case PROP_TITLE:
+      case PROP_DESCRIPTION:
         /* not writable */
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -518,6 +520,13 @@ terminal_screen_class_init (TerminalScreenClass *klass)
                           NULL,
                           G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
+  g_object_class_install_property (object_class,
+                                   PROP_DESCRIPTION,
+                                   g_param_spec_string ("description", NULL, NULL,
+                                                        NULL,
+                                                        G_PARAM_READABLE | 
+                                                        G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property
     (object_class,
      PROP_INITIAL_ENVIRONMENT,
@@ -588,11 +597,7 @@ terminal_screen_finalize (GObject *object)
 
   terminal_screen_set_profile (screen, NULL);
 
-  g_free (priv->raw_title);
-  g_free (priv->cooked_title);
-  g_free (priv->override_title);
-  g_free (priv->raw_icon_title);
-  g_free (priv->cooked_icon_title);
+  g_free (priv->title);
   g_free (priv->initial_working_directory);
   g_strfreev (priv->override_command);
   g_strfreev (priv->initial_env);
@@ -628,7 +633,7 @@ terminal_screen_new (GSettings       *profile,
   }
 
   if (title)
-    terminal_screen_set_override_title (screen, title);
+    terminal_screen_set_user_title (screen, title);
 
   priv->initial_working_directory = g_strdup (working_dir);
 
@@ -683,174 +688,45 @@ terminal_screen_exec (TerminalScreen *screen,
   return terminal_screen_do_exec (screen, data, error);
 }
 
-const char*
-terminal_screen_get_raw_title (TerminalScreen *screen)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-  
-  if (priv->raw_title)
-    return priv->raw_title;
-
-  return "";
-}
-
 const char*
 terminal_screen_get_title (TerminalScreen *screen)
 {
-  TerminalScreenPrivate *priv = screen->priv;
-  
-  if (priv->cooked_title == NULL)
-    terminal_screen_cook_title (screen);
-
-  /* cooked_title may still be NULL */
-  if (priv->cooked_title != NULL)
-    return priv->cooked_title;
-  else
-    return "";
+  return vte_terminal_get_window_title (VTE_TERMINAL (screen));
 }
 
 const char*
 terminal_screen_get_icon_title (TerminalScreen *screen)
 {
-  TerminalScreenPrivate *priv = screen->priv;
-  
-  if (priv->cooked_icon_title == NULL)
-    terminal_screen_cook_icon_title (screen);
-
-  /* cooked_icon_title may still be NULL */
-  if (priv->cooked_icon_title != NULL)
-    return priv->cooked_icon_title;
-  else
-    return "";
+  return vte_terminal_get_icon_title (VTE_TERMINAL (screen));
 }
 
 gboolean
 terminal_screen_get_icon_title_set (TerminalScreen *screen)
 {
-  return screen->priv->icon_title_set;
+  return vte_terminal_get_icon_title (VTE_TERMINAL (screen)) != NULL;
 }
 
-/* Supported format specifiers:
- * %S = static title
- * %D = dynamic title
- * %A = dynamic title, falling back to static title if empty
- * %- = separator, if not at start or end of string (excluding whitespace)
- */
-static const char *
-terminal_screen_get_title_format (TerminalScreen *screen)
+char *
+terminal_screen_get_description (TerminalScreen *screen)
 {
   TerminalScreenPrivate *priv = screen->priv;
-  static const char *formats[] = {
-    "%A"      /* TERMINAL_TITLE_REPLACE */,
-    "%D%-%S"  /* TERMINAL_TITLE_BEFORE  */,
-    "%S%-%D"  /* TERMINAL_TITLE_AFTER   */,
-    "%S"      /* TERMINAL_TITLE_IGNORE  */
-  };
-
-  return formats[g_settings_get_enum (priv->profile, TERMINAL_PROFILE_TITLE_MODE_KEY)];
-}
-
-/**
- * terminal_screen_format_title::
- * @screen:
- * @raw_title: main ingredient
- * @titleptr <inout>: pointer of the current title string
- * 
- * Format title according @format, and stores it in <literal>*titleptr</literal>.
- * Always ensures that *titleptr will be non-NULL.
- *
- * Returns: %TRUE iff the title changed
- */
-static gboolean
-terminal_screen_format_title (TerminalScreen *screen,
-                              const char *raw_title,
-                              char **titleptr)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-  const char *format, *arg;
-  const char *static_title = NULL;
-  GString *title;
-  gboolean add_sep = FALSE;
-
-  g_assert (titleptr);
+  const char *title;
 
   /* use --title argument if one was supplied, otherwise ask the profile */
-  if (priv->override_title)
-    static_title = priv->override_title;
+  if (priv->title)
+    title = priv->title;
   else
-    g_settings_get (priv->profile, TERMINAL_PROFILE_TITLE_KEY, "&s", &static_title);
+    g_settings_get (priv->profile, TERMINAL_PROFILE_TITLE_KEY, "&s", &title);
 
-  title = g_string_sized_new (128);
-
-  format = terminal_screen_get_title_format (screen);
-  for (arg = format; *arg; arg += 2)
-    {
-      const char *text_to_append = NULL;
-
-      g_assert (arg[0] == '%');
-
-      switch (arg[1])
-        {
-          case 'A':
-            text_to_append = raw_title ? raw_title : static_title;
-            break;
-          case 'D':
-            text_to_append = raw_title;
-            break;
-          case 'S':
-            text_to_append = static_title;
-            break;
-          case '-':
-            text_to_append = NULL;
-            add_sep = TRUE;
-            break;
-          default:
-            g_assert_not_reached ();
-        }
-
-      if (!text_to_append || !text_to_append[0])
-        continue;
-
-      if (add_sep && title->len > 0)
-        g_string_append (title, " - ");
-
-      g_string_append (title, text_to_append);
-      add_sep = FALSE;
-    }
-
-  if (*titleptr == NULL || strcmp (title->str, *titleptr) != 0)
-    {
-      g_free (*titleptr);
-      *titleptr = g_string_free (title, FALSE);
-      return TRUE;
-    }
-
-  g_string_free (title, TRUE);
-  return FALSE;
-}
-
-static void 
-terminal_screen_cook_title (TerminalScreen *screen)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-  
-  if (terminal_screen_format_title (screen, priv->raw_title, &priv->cooked_title))
-    g_object_notify (G_OBJECT (screen), "title");
-}
-
-static void 
-terminal_screen_cook_icon_title (TerminalScreen *screen)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-
-  if (terminal_screen_format_title (screen, priv->raw_icon_title, &priv->cooked_icon_title))
-    g_object_notify (G_OBJECT (screen), "icon-title");
+  return g_strdup_printf ("%s — %d",
+                          title && title[0] ? title : _("Terminal"),
+                          screen->priv->child_pid);
 }
 
 static void
 terminal_screen_profile_changed_cb (GSettings     *profile,
                                     const char    *prop_name,
-                                   TerminalScreen *screen)
+                                    TerminalScreen *screen)
 {
   TerminalScreenPrivate *priv = screen->priv;
   GObject *object = G_OBJECT (screen);
@@ -882,11 +758,9 @@ terminal_screen_profile_changed_cb (GSettings     *profile,
     }
 
   if (!prop_name ||
-      prop_name == I_(TERMINAL_PROFILE_TITLE_MODE_KEY) ||
       prop_name == I_(TERMINAL_PROFILE_TITLE_KEY))
     {
-      terminal_screen_cook_title (screen);
-      terminal_screen_cook_icon_title (screen);
+      g_object_notify (object, "description");
     }
 
   if (gtk_widget_get_realized (GTK_WIDGET (screen)) &&
@@ -1068,6 +942,7 @@ terminal_screen_set_profile (TerminalScreen *screen,
     g_object_unref (old_profile);
 
   g_object_notify (G_OBJECT (screen), "profile");
+  g_object_notify (G_OBJECT (screen), "description");
 }
 
 GSettings*
@@ -1458,6 +1333,8 @@ out:
   g_strfreev (env);
   free_fd_setup_data (data);
 
+  g_object_notify (G_OBJECT (screen), "description");
+
   return result;
 }
 
@@ -1604,83 +1481,33 @@ terminal_screen_button_press (GtkWidget      *widget,
   return FALSE;
 }
 
-static void
-terminal_screen_set_dynamic_title (TerminalScreen *screen,
-                                   const char     *title,
-				   gboolean	  userset)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-
-  g_assert (TERMINAL_IS_SCREEN (screen));
-  
-  if ((priv->user_title && !userset) ||
-      (priv->raw_title && title &&
-       strcmp (priv->raw_title, title) == 0))
-    return;
-
-  g_free (priv->raw_title);
-  priv->raw_title = g_strdup (title);
-  terminal_screen_cook_title (screen);
-}
-
-static void
-terminal_screen_set_dynamic_icon_title (TerminalScreen *screen,
-                                        const char     *icon_title,
-					gboolean       userset)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-  GObject *object = G_OBJECT (screen);
-  
-  g_assert (TERMINAL_IS_SCREEN (screen));
-
-  if ((priv->user_title && !userset) ||  
-      (priv->icon_title_set &&
-       priv->raw_icon_title &&
-       icon_title &&
-       strcmp (priv->raw_icon_title, icon_title) == 0))
-    return;
-
-  g_object_freeze_notify (object);
-
-  g_free (priv->raw_icon_title);
-  priv->raw_icon_title = g_strdup (icon_title);
-  priv->icon_title_set = TRUE;
-
-  g_object_notify (object, "icon-title-set");
-  terminal_screen_cook_icon_title (screen);
-
-  g_object_thaw_notify (object);
-}
-
 void
-terminal_screen_set_override_title (TerminalScreen *screen,
-                                    const char     *title)
+terminal_screen_set_user_title (TerminalScreen *screen,
+                                const char     *title)
 {
   TerminalScreenPrivate *priv = screen->priv;
-  char *old_title;
 
-  old_title = priv->override_title;
-  priv->override_title = g_strdup (title);
-  g_free (old_title);
+  g_return_if_fail (TERMINAL_IS_SCREEN (screen));
 
-  terminal_screen_set_dynamic_title (screen, title, FALSE);
-  terminal_screen_set_dynamic_icon_title (screen, title, FALSE);
+  if (g_strcmp0 (priv->title, title) == 0)
+    return;
+
+  g_free (priv->title);
+  priv->title = title && title[0] ? g_strdup (title) : NULL;
+
+  g_object_notify (G_OBJECT (screen), "description");
 }
 
 const char*
-terminal_screen_get_dynamic_title (TerminalScreen *screen)
+terminal_screen_get_user_title (TerminalScreen *screen)
 {
-  g_return_val_if_fail (TERMINAL_IS_SCREEN (screen), NULL);
-  
-  return screen->priv->raw_title;
-}
+  TerminalScreenPrivate *priv;
 
-const char*
-terminal_screen_get_dynamic_icon_title (TerminalScreen *screen)
-{
   g_return_val_if_fail (TERMINAL_IS_SCREEN (screen), NULL);
-  
-  return screen->priv->raw_icon_title;
+
+  priv = screen->priv;
+
+  return priv->title ? priv->title : _("Terminal");
 }
 
 /**
@@ -1743,18 +1570,15 @@ static void
 terminal_screen_window_title_changed (VteTerminal *vte_terminal,
                                       TerminalScreen *screen)
 {
-  terminal_screen_set_dynamic_title (screen,
-                                     vte_terminal_get_window_title (vte_terminal),
-				     FALSE);
+  g_object_notify (G_OBJECT (screen), "title");
 }
 
 static void
 terminal_screen_icon_title_changed (VteTerminal *vte_terminal,
                                     TerminalScreen *screen)
 {
-  terminal_screen_set_dynamic_icon_title (screen,
-                                          vte_terminal_get_icon_title (vte_terminal),
-					  FALSE);
+  g_object_notify (G_OBJECT (screen), "icon-title");
+  g_object_notify (G_OBJECT (screen), "icon-title-set");
 }
 
 static void
@@ -1773,6 +1597,8 @@ terminal_screen_child_exited (VteTerminal *terminal)
   priv->child_pid = -1;
   priv->pty_fd = -1;
   
+  g_object_notify (G_OBJECT (screen), "description");
+
   action = g_settings_get_enum (priv->profile, TERMINAL_PROFILE_EXIT_ACTION_KEY);
   
   switch (action)
@@ -1817,24 +1643,6 @@ terminal_screen_child_exited (VteTerminal *terminal)
     }
 }
 
-void
-terminal_screen_set_user_title (TerminalScreen *screen,
-                                const char *text)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-
-  /* The user set the title to nothing, let's understand that as a
-     request to revert to dynamically setting the title again. */
-  if (!text || !text[0])
-    priv->user_title = FALSE;
-  else
-    {
-      priv->user_title = TRUE;
-      terminal_screen_set_dynamic_title (screen, text, TRUE);
-      terminal_screen_set_dynamic_icon_title (screen, text, TRUE);
-    }
-}
-
 static void
 terminal_screen_drag_data_received (GtkWidget        *widget,
                                     GdkDragContext   *context,
@@ -2091,42 +1899,6 @@ terminal_screen_check_match (TerminalScreen *screen,
   return NULL;
 }
 
-#include "terminal-options.h"
-
-void
-terminal_screen_save_config (TerminalScreen *screen,
-                             GKeyFile *key_file,
-                             const char *group)
-{
-  TerminalScreenPrivate *priv = screen->priv;
-  VteTerminal *terminal = VTE_TERMINAL (screen);
-  const char *profile_id;
-  char *working_directory;
-
-  g_settings_get (priv->profile, TERMINAL_PROFILE_NAME_KEY, "&s", &profile_id);
-  g_key_file_set_string (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_PROFILE_ID, profile_id);
-
-  if (priv->override_command)
-    terminal_util_key_file_set_argv (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_COMMAND,
-                                     -1, priv->override_command);
-
-  if (priv->override_title)
-    g_key_file_set_string (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_TITLE, priv->override_title);
-
-  /* FIXMEchpe: use the initial_working_directory instead?? */
-  working_directory = terminal_screen_get_current_dir (screen);
-  if (working_directory)
-    terminal_util_key_file_set_string_escape (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_WORKING_DIRECTORY, working_directory);
-  g_free (working_directory);
-
-  g_key_file_set_double (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_ZOOM, priv->font_scale);
-
-  g_key_file_set_integer (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_WIDTH,
-                          vte_terminal_get_column_count (terminal));
-  g_key_file_set_integer (key_file, group, TERMINAL_CONFIG_TERMINAL_PROP_HEIGHT,
-                          vte_terminal_get_row_count (terminal));
-}
-
 /**
  * terminal_screen_has_foreground_process:
  * @screen:
@@ -2176,3 +1948,11 @@ terminal_screen_has_foreground_process (TerminalScreen *screen)
   return TRUE;
 #endif
 }
+
+const char *
+terminal_screen_get_uuid (TerminalScreen *screen)
+{
+  g_return_val_if_fail (TERMINAL_IS_SCREEN (screen), NULL);
+
+  return screen->priv->uuid;
+}
